@@ -11,12 +11,24 @@ def test_postprocessor():
     ]
     labels = [ClassificationLabel(**label) for label in labels]
     labels = ClassificationLabels(labels)
-    stop_labels = {'PERSON'}
     mapping = {'Facility': 'ORG'}
-    processor = PostProcessor(stop_labels=stop_labels, mapping=mapping)
+    processor = PostProcessor(mapping=mapping)
     labels = processor.transform(labels).dict()
     expected = [
         {'label': 'ORG'},
-        {'label': 'ORG'}
     ]
     assert labels == expected
+
+
+def test_to_dict():
+    expected = {'Facility': 'ORG'}
+    processor = PostProcessor(mapping=expected)
+    actual = processor.to_dict()
+    assert actual == expected
+
+
+def test_load():
+    expected = {'Facility': 'ORG'}
+    processor = PostProcessor.load(mapping=expected)
+    actual = processor.mapping
+    assert actual == expected
